@@ -4,11 +4,13 @@ from poisson_approval.constants.constants import *
 from poisson_approval.constants.EquilibriumStatus import EquilibriumStatus
 from poisson_approval.containers.AnalyzedStrategies import AnalyzedStrategies
 from poisson_approval.containers.Winners import Winners
-from poisson_approval.strategies.StrategyOrdinal import StrategyOrdinal
+from poisson_approval.iterables.IterableStrategyOrdinal import IterableStrategyOrdinal
 from poisson_approval.strategies.StrategyThreshold import StrategyThreshold
 from poisson_approval.utils.computation_engine import computation_engine
 from poisson_approval.utils.SetPrintingInOrder import SetPrintingInOrder
-from poisson_approval.utils.Util import is_lover, my_division, sort_ballot, ballot_low_u, ballot_high_u, product_dict
+from poisson_approval.utils.Util import my_division
+from poisson_approval.utils.UtilPreferences import is_lover
+from poisson_approval.utils.UtilBallots import sort_ballot
 from poisson_approval.utils.UtilCache import cached_property, DeleteCacheMixin, property_deleting_cache
 
 
@@ -302,12 +304,7 @@ class Profile(DeleteCacheMixin):
         --------
         Cf. :class:`ProfileOrdinal`.
         """
-        d_ranking_possible_ballots = {ranking: [ballot_low_u(ranking, self.voting_rule),
-                                                ballot_high_u(ranking, self.voting_rule)]
-                                      if self.d_ranking_share[ranking] > 0 else ['']
-                                      for ranking in RANKINGS}
-        for d_ranking_ballot in product_dict(d_ranking_possible_ballots):
-            yield StrategyOrdinal(d_ranking_ballot, profile=self, voting_rule=self.voting_rule)
+        return IterableStrategyOrdinal(profile=self)
 
     @property
     def strategies_pure(self):
@@ -456,7 +453,7 @@ class Profile(DeleteCacheMixin):
     def random_strategy(cls, **kwargs):
         """Random strategy.
 
-        This is a default generator of random strategies. It is used, for example, in
+        This is a default factory of random strategies. It is used, for example, in
         :class:`ProfileCardinal.iterated_voting`.
 
         Returns
