@@ -4,7 +4,7 @@ import numpy as np
 from fractions import Fraction
 from poisson_approval.constants.constants import *
 from poisson_approval.constants.EquilibriumStatus import EquilibriumStatus
-from poisson_approval.generators.GeneratorStrategyThresholdUniform import GeneratorStrategyThresholdUniform
+from poisson_approval.random_factories.RandStrategyThresholdUniform import RandStrategyThresholdUniform
 from poisson_approval.profiles.Profile import Profile
 from poisson_approval.strategies.Strategy import Strategy
 from poisson_approval.strategies.StrategyThreshold import StrategyThreshold
@@ -12,8 +12,8 @@ from poisson_approval.tau_vector.TauVector import TauVector
 from poisson_approval.utils.ComputationEngineNumeric import ComputationEngineNumeric
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 from poisson_approval.utils.Util import candidates_to_probabilities, my_division, array_to_d_candidate_value, \
-    one_over_t_plus_one, ballot_one, ballot_one_two, ballot_low_u, ballot_high_u, \
-    to_callable, candidates_to_d_candidate_probability
+    one_over_t_plus_one, to_callable, candidates_to_d_candidate_probability
+from poisson_approval.utils.UtilBallots import ballot_one, ballot_one_two, ballot_low_u, ballot_high_u
 from poisson_approval.utils.UtilCache import cached_property, property_deleting_cache
 
 
@@ -42,6 +42,8 @@ class ProfileCardinal(Profile):
     well_informed_voters = property_deleting_cache('_well_informed_voters')
     ratio_fanatic = property_deleting_cache('_ratio_fanatic')
 
+    is_continuous = False
+
     def have_ranking_with_utility_above_u(self, ranking, u):
         """Share of voters who have a given ranking and strictly above a given utility for their middle candidate.
 
@@ -553,15 +555,15 @@ class ProfileCardinal(Profile):
     def random_strategy(cls, **kwargs):
         """Random strategy.
 
-        This is a default generator of random strategies. It is used, for example, in
+        This is a default factory of random strategies. It is used, for example, in
         :class:`ProfileCardinal.iterated_voting`.
 
         Returns
         -------
         StrategyThreshold
-            Uses :class:`GeneratorStrategyThresholdUniform`.
+            Uses :class:`RandStrategyThresholdUniform`.
         """
-        return GeneratorStrategyThresholdUniform(**kwargs)()
+        return RandStrategyThresholdUniform(**kwargs)()
 
 
 def _my_round(x):
